<?php
/**
 * All admin facing functions
 */
namespace Codexpert\CoDesigner_Pro\App;
use Codexpert\Plugin\Base;
use Codexpert\Plugin\Metabox;
use Codexpert\CoDesigner\Helper;

/**
 * if accessed directly, exit.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @package Plugin
 * @subpackage Admin
 * @author Codexpert <hi@codexpert.io>
 */
class Admin extends Base {

	public $plugin;

	/**
	 * Constructor function
	 */
	public function __construct( $plugin ) {
		$this->plugin	= $plugin;
		$this->slug		= $this->plugin['TextDomain'];
		$this->name		= $this->plugin['Name'];
		$this->server	= $this->plugin['server'];
		$this->version	= $this->plugin['Version'];
	}

	/**
	 * Internationalization
	 */
	public function i18n() {
		load_plugin_textdomain( 'codesigner-pro', false, CODESIGNER_PRO_DIR . '/languages/' );
	}

	public function upgrade() {
		if( $this->version == get_option( "{$this->slug}_db-version" ) ) return;
		update_option( "{$this->slug}_db-version", $this->version, false );

		// upgrader actions
	}

	/**
	 * Enqueue JavaScripts and stylesheets
	 */
	public function enqueue_scripts() {
		$min = defined( 'CODESIGNER_PRO_DEBUG' ) && CODESIGNER_PRO_DEBUG ? '' : '.min';
		
		wp_enqueue_style( $this->slug, plugins_url( "/assets/css/admin{$min}.css", CODESIGNER_PRO ), '', $this->version, 'all' );
		wp_enqueue_script( $this->slug, plugins_url( "/assets/js/admin{$min}.js", CODESIGNER_PRO ), [ 'jquery' ], $this->version, true );

	    // wp_enqueue_style( "{$this->slug}-react", plugins_url( 'build/index.css', CODESIGNER_PRO ) );
	    // wp_enqueue_script( "{$this->slug}-react", plugins_url( 'build/index.js', CODESIGNER_PRO ), [ 'wp-element' ], '1.0.0', true );

	    
	    $localized = [
	    	'homeurl'		=> get_bloginfo( 'url' ),
	    	'adminurl'		=> admin_url(),
	    	'asseturl'		=> CODESIGNER_PRO_ASSETS,
	    	'ajaxurl'		=> admin_url( 'admin-ajax.php' ),
	    	'_wpnonce'		=> wp_create_nonce(),
	    	'api_base'		=> get_rest_url(),
	    	'rest_nonce'	=> wp_create_nonce( 'wp_rest' ),
	    ];
	    wp_localize_script( $this->slug, 'CODESIGNER_PRO', apply_filters( "{$this->slug}-localized", $localized ) );
	}

	public function plugin_row_meta( $plugin_meta, $plugin_file ) {
		
		if ( $this->plugin['basename'] === $plugin_file ) {
			$plugin_meta['help'] = '<a href="https://help.codexpert.io/" target="_blank" class="cx-help">' . __( 'Help', 'codesigner-pro' ) . '</a>';
		}

		return $plugin_meta;
	}

	public function update_cache( $post_id, $post, $update ) {
		wp_cache_delete( "codesigner_pro_{$post->post_type}", 'codesigner_pro' );
	}

	public function footer_text( $text ) {
		if( get_current_screen()->parent_base != $this->slug ) return $text;

		return sprintf( __( 'If you like <strong>%1$s</strong>, please <a href="%2$s" target="_blank">leave us a %3$s rating</a> on WordPress.org! It\'d motivate and inspire us to make the plugin even better!', 'codesigner-pro' ), $this->name, "https://wordpress.org/support/plugin/{$this->slug}/reviews/?filter=5#new-post", '⭐⭐⭐⭐⭐' );
	}

	public function modal() {
		echo '
		<div id="codesigner-pro-modal" style="display: none">
			<img id="codesigner-pro-modal-loader" src="' . esc_attr( CODESIGNER_PRO_ASSETS . '/img/loader.gif' ) . '" />
		</div>';
	}

	public function widget_links( $links ) {
		unset( $links['gopro'] );

		return $links;
	}

	public function supports_payment_form( $supports, $features, $ins  )	{
		if( $features == 'payment_form' && wcd_is_edit_mode() ) {
			return false;
		}

		return $supports;
	}

	public function pseudo_page_ids( $posts )	{
		$posts['home'] = __( 'Home', 'codesigner-pro' );

		return $posts;
	}

	public function attribute_color_field() {

		$product_taxonomy = [];
		if ( function_exists( 'wcd_get_taxonomies' ) ) {
			$product_taxonomy = wcd_get_taxonomies();
		}

		foreach ( $product_taxonomy as $_taxonomy => $value ) {
			add_action( "{$_taxonomy}_add_form_fields", function() {
				?>
				<div class="form-field term-color-wrap">
					<label for="tag-color">Color</label>
					<input type="color" id="wl-color" name="wl-color" value="#ff0000">
					<p>Input color if you want to use this as color taxonomy for CoDesigner Advance Search Widget.</p>
				</div>
				<?php
			} );
			add_action( "{$_taxonomy}_edit_form", function() {
				$term_id 	= sanitize_text_field( $_GET['tag_ID'] );
				$color  	= get_term_meta( $term_id, 'wl-color' ) ? get_term_meta( $term_id, 'wl-color', true ) : '#ff0000'; 
				?>
				<div class="form-field term-color-wrap">
					<label for="tag-color" style="display: inline-block;width: 215px;">Color</label>
					<input type="color" id="wl-color" name="wl-color" value="<?php esc_attr_e( $color ); ?>">
					<p style="margin-left: 27%;">Input color if you want to use this as color taxonomy for CoDesigner Advance Search Widget.</p>
				</div>
				<?php
			} );

			add_action( 'create_term', function( $term_id, $tt_id, $taxonomy ) {
				if ( isset( $_POST['wl-color'] ) ) {
					update_term_meta( $term_id,'wl-color', sanitize_text_field( $_POST['wl-color'] ) );
				}			}, 10, 3 );
			add_filter( 'wp_update_term_data', function( $data, $term_id, $taxonomy, $args  ) {
				if ( isset( $_POST['wl-color'] ) ) {
					update_term_meta( $term_id,'wl-color', sanitize_text_field( $_POST['wl-color'] ) );
				}
			} ,10,4 );
		}
	}	
}